diff --git replace/ahah.js replace/ahah.js
index da9d091..cd405b7 100644
--- replace/ahah.js
+++ replace/ahah.js
@@ -117,8 +117,9 @@ Drupal.ahah = function(base, element_settings) {
  * Handler for the form redirection submission.
  */
 Drupal.ahah.prototype.beforeSubmit = function (form_values, element, options) {
-  // Disable the element that received the change.
-  $(this.element).addClass('progress-disabled').attr('disabled', true);
+  // Hide the element that received the change. We can't disable it as the
+  // element won't be submitted if it's disabled.
+  $(this.element).addClass('progress-disabled').hide();
 
   // Insert progressbar or throbber.
   if (this.progress.type == 'bar') {
@@ -164,7 +165,7 @@ Drupal.ahah.prototype.success = function (response, status) {
   if (this.progress.object) {
     this.progress.object.stopMonitoring();
   }
-  $(this.element).removeClass('progress-disabled').attr('disabled', false);
+  $(this.element).removeClass('progress-disabled').show();
 
   // Add the new content to the page.
   Drupal.freezeHeight();
@@ -217,5 +218,5 @@ Drupal.ahah.prototype.error = function (response, uri) {
   // Undo hide.
   $(this.wrapper).show();
   // Re-enable the element.
-  $(this.element).removeClass('progess-disabled').attr('disabled', false);
+  $(this.element).removeClass('progess-disabled').show();
 };
